@@ -1,9 +1,9 @@
 package Health::BladderDiary::GenTable;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-11-12'; # DATE
+our $DATE = '2020-11-13'; # DATE
 our $DIST = 'Health-BladderDiary-GenTable'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -93,6 +93,7 @@ sub gen_bladder_diary_table_from_entries {
             }
 
             $uentry =~ /\b(\d+)ml\b/     and $parsed_entry->{vol}     //= $1;
+            $uentry =~ /\bv(\d+)\b/      and $parsed_entry->{vol}     //= $1;
             $uentry =~ /\bu([0-9]|10)\b/ and $parsed_entry->{urgency} //= $1;
             $uentry =~ /\bc([0-6])\b/    and $parsed_entry->{color}   //= do {
                 if    ($1 == 0) { 'clear' } # very good
@@ -147,7 +148,7 @@ sub gen_bladder_diary_table_from_entries {
             last unless @intakes || @urinations;
 
             my @hour_rows;
-            push @hour_rows, {time => sprintf("%02d-%02d.00", $h, $h+1 <= 23 ? $h+1 : 0)};
+            push @hour_rows, {time => sprintf("%02d.00-%02d.00", $h, $h+1 <= 23 ? $h+1 : 0)};
 
             my $j = 0;
             while (@intakes && $intakes[0]{_h} == $h) {
@@ -260,7 +261,7 @@ Health::BladderDiary::GenTable - Create bladder diary table from entries
 
 =head1 VERSION
 
-This document describes version 0.002 of Health::BladderDiary::GenTable (from Perl distribution Health-BladderDiary-GenTable), released on 2020-11-12.
+This document describes version 0.003 of Health::BladderDiary::GenTable (from Perl distribution Health-BladderDiary-GenTable), released on 2020-11-13.
 
 =head1 SYNOPSIS
 
